%%%%%%%%%%%%%%%%%%  Demo for designing sparse sensing matrix
%%% "Optimized Sparse Projections for Compressive Sensing,"
%%%  https://arxiv.org/abs/1709.06895.  
%%%  by T. Hong, X. Li, Z. Zhu, and Qiuwei Li

clear;close all;
addpath('tools');
load('Psi_big.mat')               %load the trained Dictionary and the corresponding Coeffcient matrix,which is obtained via K-SVD algorithm using the training data

%read the image====================================================
pathForImages ='images/';
imageName = 'lena512.png';
image = imread(strcat([pathForImages,imageName]));
image = double(image);
blocksize = 16;
image_or = image;
%param setting=============================================================
K = 16;                              %the sparsity
M = 80;                             %the dimension of sensing matrix
N = blocksize^2;
k = 30


%test the differenet kinds of designing sensing matrix=====================

% CS_randn========================================================
randn('state',1)
Phi_randn = randn(M,N); %the optimal sensing matrix used in CS_randn
[ X_randn,PSNR_randn ] = image_recons( Phi_randn, Psi, image,K,blocksize  );
PSNR_randn
%===============================================================

% CS_sparse Binary=======================================================
Phi_sparse_binary = zeros(M,N);
for I = 1:M
    randnposi= randperm(N);
    Phi_sparse_binary(I,randnposi(1:ceil(k))) =randn(1,ceil(k));
end
[ X_sparse_binary,PSNR_sparse_binary] = image_recons( Phi_sparse_binary, Psi, image,K,blocksize  );
PSNR_sparse_binary
%===============================================================

% CS_sparse-IHTA=======================================================
[Phi_sparse_IHTA] = SparseSensing( dctmtx(N),Psi,k,0.5,M,1);
[ X_sparse_IHTA,PSNR_sparse_IHTA] = image_recons( Phi_sparse_IHTA, Psi, image,K,blocksize  );
PSNR_sparse_IHTA
%===============================================================

% CS_sparse-IHT=======================================================
[Phi_sparse_IHT] = SparseSensing( eye(N),Psi,k,0.5,M,1);
[ X_sparse_IHT,PSNR_sparse_IHT] = image_recons( Phi_sparse_IHT, Psi, image,K,blocksize  );
PSNR_sparse_IHT
%===============================================================
